/*
 * Copyright (C) 2005 Edd Dumbill <edd@gnome.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

using System;
using System.IO;
using Gtk;
using GLib;

class MainClass
{
	ChannelWindow channels;
	Store store;
	public static Gdk.Pixbuf program_pixbuf;
	public static Gdk.Pixbuf program_pixbuf16;
	public static Gdk.Pixbuf program_pixbuf48;
	
	public static void Main (string[] args)
	{
		Application.Init ();

		// LogFunc logFunc = new LogFunc (Log.PrintTraceLogFunction);
		// Log.SetLogHandler ("GLib-GObject", LogLevelFlags.Critical, logFunc);
		
		program_pixbuf = new Gdk.Pixbuf (null, "podcast.png");  
		program_pixbuf16 = program_pixbuf.ScaleSimple (16, 16, Gdk.InterpType.Hyper);
		program_pixbuf48 = program_pixbuf.ScaleSimple (48, 48, Gdk.InterpType.Hyper);
		new MainClass ();
		Application.Run ();
	}

	private Menu popupMenu;
	
	public MainClass()
	{
		string userdir = Path.Combine (
			Environment.GetFolderPath(System.Environment.SpecialFolder.Personal),
			"Monopod");
		
		// check userdir exists, make if not
		if (!Directory.Exists (userdir)) {
			DirectoryInfo d = Directory.CreateDirectory (userdir);
			if ( d == null ) {
				// TODO: throw a wobbly
			}
		}	
		store = new Store (Path.Combine (userdir, ".monopod.db"), userdir);
		channels = new ChannelWindow (store);
		
		// kick off downloading
		store.FetchNextChannel ();
		store.FetchNextCast ();
		
		if (store.NumberOfChannels == 0)
			store.AddDefaultChannels ();

		InitIcon ();
		InitMenu ();
	}
	
	private void InitIcon()
	{
		EventBox eb = new EventBox();
		
		eb.Add (new Image(program_pixbuf16)); // using stock icon
		// hooking event
		eb.ButtonPressEvent += new ButtonPressEventHandler (this.OnImageClick);
		Egg.TrayIcon icon = new Egg.TrayIcon("Test");
		icon.Add(eb);
		// showing the trayicon
		icon.ShowAll();
	}
	
	private void InitMenu ()
	{
      	popupMenu = new Menu();  
      	MenuItem item = new MenuItem ("Subscriptions");
      	item.Activated += new EventHandler (this.OnSubscriptions);
      	popupMenu.Add (item);
      	ImageMenuItem aboutItem = new ImageMenuItem ("About");
      	aboutItem.Image  = new Image (Gnome.Stock.About, IconSize.Menu);
      	popupMenu.Add (aboutItem); 
      	ImageMenuItem menuPopup1 = new ImageMenuItem ("Quit");
      	Image appimg = new Image (Gtk.Stock.Quit, IconSize.Menu );
      	menuPopup1.Image = appimg;
      	popupMenu.Add(menuPopup1);


      	menuPopup1.Activated += OnQuit;
      	aboutItem.Activated += OnAbout;
		popupMenu.ShowAll();

	} 
	
	private void OnImageClick (object o, ButtonPressEventArgs args) // handler for mouse click
	{
   		if (args.Event.Button == 3) //right click
		{
      		popupMenu.Popup(null, null, null, IntPtr.Zero, args.Event.Button,
      			args.Event.Time);
   		}
	}
	
	private void OnSubscriptions (object o, EventArgs args)
	{
		channels.Run ();
	}
	
	private void OnQuit (object o, EventArgs args)
	{
		Application.Quit(); // quits the application when the users clicks the popup menu
	}
	
	private void OnAbout (object o, EventArgs args)
	{
		Gnome.About about;		
		// TODO: make use AssemblyInfo for version
		about = new Gnome.About ("Monopod",
			"0.2",
			"Copyright © 2005 Edd Dumbill",
			"A simple podcast client.", 
			new string[] {"Edd Dumbill <edd@gnome.org>"},
			new string[] {}, null, program_pixbuf48);
		about.Icon = program_pixbuf16;
		about.Show ();
	}
}
